:mod:`art.attacks`
==================
.. automodule:: art.attacks

Base Class Attacks
------------------
.. autoclass:: Attack
   :members:

Base Class Evasion Attacks
--------------------------
.. autoclass:: EvasionAttack
   :members:

Base Class Poisoning Attacks
----------------------------
.. autoclass:: PoisoningAttack
.. autoclass:: PoisoningAttackBlackBox
.. autoclass:: PoisoningAttackWhiteBox
.. autoclass:: PoisoningAttackTransformer
   :members:

Base Class Extraction Attacks
-----------------------------
.. autoclass:: ExtractionAttack
   :members:

Base Class Inference Attacks
----------------------------
.. autoclass:: InferenceAttack
.. autoclass:: AttributeInferenceAttack
   :members:
